@@ -18,12 +18,10 @@ use function is_array;
 use function is_scalar;
 use function is_string;
 use function ltrim;
-use function method_exists;
 use function rtrim;
 use function sprintf;
 use function str_contains;
 use function str_replace;
-use function strpos;
 use function strrpos;
 use function strtolower;
 use function substr;
@@ -90,10 +88,7 @@ class ClassGenerator extends AbstractGenerator implements TraitUsageInterface
 
         $cg->setAbstract($classReflection->isAbstract());
         $cg->setFinal($classReflection->isFinal());
-
-        if (method_exists($classReflection, 'isReadonly')) {
-            $cg->setReadonly((bool) $classReflection->isReadonly());
-        }
+        $cg->setReadonly($classReflection->isReadonly());
 
         // set the namespace
         if ($classReflection->inNamespace()) {
@@ -185,7 +180,6 @@ class ClassGenerator extends AbstractGenerator implements TraitUsageInterface
      * @configkey properties
      * @configkey methods
      * @throws Exception\InvalidArgumentException
-     * @param  array $array
      * @return static
      */
     public static function fromArray(array $array)
@@ -534,11 +528,7 @@ class ClassGenerator extends AbstractGenerator implements TraitUsageInterface
      */
     public function getConstant($constantName)
     {
-        if (isset($this->constants[$constantName])) {
-            return $this->constants[$constantName];
-        }
-
-        return false;
+        return $this->constants[$constantName] ?? false;
     }
 
     /**
