@@ -3,12 +3,11 @@
 namespace LaminasTest\Code\Generator;
 
 use Laminas\Code\Generator\PropertyValueGenerator;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @group Laminas_Code_Generator
- * @group Laminas_Code_Generator_Php
- */
+#[Group('Laminas_Code_Generator')]
+#[Group('Laminas_Code_Generator_Php')]
 class PropertyValueGeneratorTest extends TestCase
 {
     public function testPropertyValueAddsSemicolonToValueGenerator()
